@@ -56,7 +56,7 @@ errorLocalizer <- function(E, x, ...){
 #' Localize errors in numerical data
 #'
 #' @method errorLocalizer editmatrix
-#' @param weight a \code{lengt(x)} positive weight vector
+#' @param weight a \code{lengt(x)} positive weight vector. The weights are assumed to be in the same order as the variables in \code{x}.
 #' @param maxadapt maximum number of variables to adapt
 #' @param maxweight maximum weight of solution, if weights are not given, this is equal to the 
 #' maximum number of variables to adapt. 
@@ -72,12 +72,18 @@ errorLocalizer.editmatrix <- function(
             maxweight=sum(weight),
             maxduration=600,
             ...){
-    stopifnot(is.numeric(weight), all(!is.na(weight)), all(weight>=0))
+    stopifnot(
+        is.numeric(weight), 
+        all(!is.na(weight)), 
+        all(weight>=0), 
+        length(weight)==length(x)
+    )
 
     if ( !isNormalized(E) ) E <- normalize(E)
     # missings must be adapted, others still have to be treated.
     adapt <- is.na(x)   
     vars <- getVars(E)
+    if (!all(vars %in% names(x)) ) stop('E contains variables not in record')
 
     o <- order(weight[!adapt], decreasing=TRUE)
     totreat <- names(x)[!adapt][o]
@@ -87,14 +93,17 @@ errorLocalizer.editmatrix <- function(
     # if variables do not occur in editmatrix, do not adapt.
     adapt[!(names(adapt) %in% vars)] <- FALSE
     # Eliminate missing variables.
-    for (v in names(x)[is.na(x)]) E <- eliminate.editmatrix(E,v)
+    vs <- names(x)
+    elimvars <- vs[vs %in% vars & is.na(x)]
+    for (v in elimvars) E <- eliminate.editmatrix(E,v)
+    wsol <- min(sum(weight[vars %in% totreat | adapt[vars]]), maxweight)
 
-    wsol <- min(sum(weight[vars %in% totreat]), maxweight)
     cp <- backtracker(
         maxduration=maxduration,
         isSolution = {
 
             w <- sum(weight[adapt])
+
             if ( w > min(wsol,maxweight) 
               || sum(adapt) > maxadapt
               || isObviouslyInfeasible.editmatrix(.E)
@@ -163,16 +172,23 @@ errorLocalizer.editarray <- function(
     maxweight=sum(weight),
     maxduration=600,
     ...){
-    stopifnot(is.numeric(weight), all(!is.na(weight)), all(weight>=0))
+    
+    stopifnot(
+        is.numeric(weight), 
+        all(!is.na(weight)), 
+        all(weight>=0), 
+        length(weight)==length(x)
+    )
     adapt <- is.na(x)
 
+    vars <- getVars.editarray(E)
+    if (!all(vars %in% names(x)) ) stop('E contains variables not in record')
 
     o <- order(weight[!adapt], decreasing=TRUE)
     totreat <- names(x)[!adapt][o]
 
-    vars <- getVars.editarray(E)
     for (v in vars[adapt & names(x) %in% vars]) E <- eliminate.editarray(E,v)
-    wsol <- min(sum(weight[vars %in% totreat]),maxweight)
+    wsol <- min(sum(weight[vars %in% totreat | adapt[vars]]),maxweight)
     ind <- getInd(E)
     bt <- backtracker(
         isSolution = {
